/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { OnInit } from '@angular/core';
import { MatSort, SortDirection } from '@angular/material/sort';
import { IconDefinition } from '@fortawesome/free-solid-svg-icons';
import { SortOption } from '../../interfaces/sort-option.interface';
import { FormControl, FormGroup } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * A custom component meant to allow user to change sort order for paged
 * collections. This is basically just a wrapper around `MatSelect` providing
 * some additional display details and an @Output emitter for the field to
 * sort on and order selected needed in the parent component to handle the
 * sort change for the collection.
 */
export declare class SorterComponent extends MatSort implements OnInit {
    /** Text displayed for active selection in select drop down. */
    activeDisplay?: string;
    /** The icon used for displaying current sort order. */
    faSort: IconDefinition;
    /** The form with the sort select drop down. */
    form: FormGroup;
    /** The options to display in the select drop down. */
    selectOptions: {
        field: string;
        icon: IconDefinition;
        order: SortDirection;
        text: string;
    }[];
    /** The control for the sort select drop down. */
    sortControl: FormControl;
    /** The list of fields to include in the sort. */
    options: SortOption[] | string[];
    constructor();
    /**
     * Lifecycle method automatically called by angular when the component is
     * initialized.
     */
    ngOnInit(): void;
    /**
     * Handler for when the user selects an option in the drop down. Emits the
     * needed sort event to the parent so it can handle changing the sort
     * order for the data in the collection.
     *
     * @param event The value selected in the drop down.
     */
    onSelectionChange(val: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SorterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SorterComponent, "ngx-mat-sorter", never, { "options": "options"; }, {}, never, never>;
}
